
#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <gtkmozembedmm/wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "webcontrol.h"

extern "C"
{

//Declarations of the *_get_type() functions:

GType gtk_moz_embed_get_type(void);

//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:

namespace Mozilla {  class WebControl_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }

namespace Mozilla { 

void wrap_init()
{
  // Register Error domains:

// Map gtypes to gtkmm wrapper-creation functions:
  Glib::wrap_register(gtk_moz_embed_get_type(), &Mozilla::WebControl_Class::wrap_new);

  // Register the gtkmm gtypes:
  Mozilla::WebControl::get_type();

} // wrap_init()

} //Mozilla


